from math import floor

from django import template
from django.templatetags.static import static

register = template.Library()

@register.filter
def cover_image_data(album):
    """
    Palauttaa dictin: url, width, height, aspect_ratio.
    Jos coveria ei ole, palauttaa placeholder-kuvan ja oletusmitat.
    """
    photo = getattr(album, "cover", None)
    max_w, max_h = 720, 720

    if not photo or not photo.width or not photo.height:
        return {
            "url": static("img/placeholder.png"),
            "width": 1200,
            "height": 800,
            "aspect_ratio": round(1200 / 800, 3),
        }

    aspect = photo.aspect_ratio

    if photo.width > photo.height:
        w = min(photo.width, max_w)
        h = floor(w / aspect)
    else:
        h = min(photo.height, max_h)
        w = floor(h * aspect)

    return {
        "url": photo.photo_md.url,
        "width": w,
        "height": h,
        "aspect_ratio": round(aspect, 3),
    }
